==> haskell-descriptive-0.9.5-263-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 descriptive
version:              0.9.5
visibility:           public
id:                   descriptive-0.9.5-xtcfPi2pUv81o0l67ztVn
key:                  descriptive-0.9.5-xtcfPi2pUv81o0l67ztVn
license:              BSD-3-Clause
copyright:            2015 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
stability:            Experimental
homepage:             https://github.com/chrisdone/descriptive
synopsis:
    Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.

description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.

category:             Parsing
abi:                  6fad20f614f9a26a773277e9e44bbc4b
exposed:              True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options

hidden-modules:       Descriptive.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/descriptive-0.9.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/descriptive-0.9.5
hs-libraries:         HSdescriptive-0.9.5-xtcfPi2pUv81o0l67ztVn
depends:
    aeson-1.5.6.0-5GxEynAdVr82B7C7yhxG6H base-4.15.0.0
    bifunctors-5.5.11-765yoGpReeH1sHcQgjyDoE containers-0.6.4.1
    mtl-2.2.2 scientific-0.3.7.0-6YcEb7tz99ZGgIPqqFBkeZ text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.3.1-BYdg1PRFj4WB38iHU29MVy

haddock-interfaces:   /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html:         /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.5-265-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 descriptive
version:              0.9.5
visibility:           public
id:                   descriptive-0.9.5-KuWyXNEjcV5KM1vHNDkpNj
key:                  descriptive-0.9.5-KuWyXNEjcV5KM1vHNDkpNj
license:              BSD-3-Clause
copyright:            2015 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
stability:            Experimental
homepage:             https://github.com/chrisdone/descriptive
synopsis:
    Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.

description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.

category:             Parsing
abi:                  cfabd4303cfdde912deb1cca69d41777
exposed:              True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options

hidden-modules:       Descriptive.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/descriptive-0.9.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/descriptive-0.9.5
hs-libraries:         HSdescriptive-0.9.5-KuWyXNEjcV5KM1vHNDkpNj
depends:
    aeson-1.5.6.0-FCXpoR7la5e15i9FMLdjlO base-4.15.0.0
    bifunctors-5.5.11-LyPL7W1wK6YBOsBrk318Ef containers-0.6.4.1
    mtl-2.2.2 scientific-0.3.7.0-CP2rRIG39lTCDzlWk45agq text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.3.1-EtdN61cdG6Y4MwC0gVwGz6

haddock-interfaces:   /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html:         /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
